.. currentmodule:: sardana.pool.poolcontroller

:mod:`~sardana.pool.poolcontroller`
======================================

.. automodule:: sardana.pool.poolcontroller

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`PoolController`
    * :class:`PoolPseudoMotorController`
    * :class:`PoolPseudoCounterController`
    
PoolController
-------------------

.. inheritance-diagram:: PoolController
    :parts: 1
    
.. autoclass:: PoolController
    :show-inheritance:
    :members:
    :undoc-members:

PoolPseudoMotorController
--------------------------

.. inheritance-diagram:: PoolPseudoMotorController
    :parts: 1
    
.. autoclass:: PoolPseudoMotorController
    :show-inheritance:
    :members:
    :undoc-members:

PoolPseudoCounterController
----------------------------

.. inheritance-diagram:: PoolPseudoCounterController
    :parts: 1
    
.. autoclass:: PoolPseudoCounterController
    :show-inheritance:
    :members:
    :undoc-members:
    